-- gui for license plates

LicensePlatesGui = {}
local LicensePlatesGui_mt = Class(LicensePlatesGui, YesNoDialog)

-- used elements from xml
LicensePlatesGui.CONTROLS = {
	"dialogTitleElement",
	"visibilityElement",
	"visibilityTitleElement",
	"textElement",
	"textTitleElement1",
	"textTitleElement2",
	"textTitleElement3",
	"symbolColorElement",
	"symbolColorTitleElement"
}

-- state to symbol color and back
LicensePlatesGui.S2S = {
	"black",
	"green",
	"red",
	black = 1,
	green = 2,
	red = 3
}

-- create new gui
function LicensePlatesGui:new()
	local self = YesNoDialog:new(nil, LicensePlatesGui_mt)

	self:registerControls(LicensePlatesGui.CONTROLS)

	return self
end

-- set current values
function LicensePlatesGui:setData(isVisible, text, symbolColor)
	self.dialogTitleElement:setText(g_i18n:getText("input_LICENSE_PLATE_CHANGE"))

	self.visibilityTitleElement:setText(g_i18n:getText("licensePlatesVisibilityTitle"))
	self.visibilityElement:setTexts({
		g_i18n:getText("licensePlatesInvisible"),
		g_i18n:getText("licensePlatesVisible")
	})
	self.visibilityElement:setState(isVisible and 2 or 1, true)

	self.textTitleElement1:setText(g_i18n:getText("licensePlatesTextTitle1"))
	self.textTitleElement2:setText(g_i18n:getText("licensePlatesTextTitle2"))
	self.textTitleElement3:setText(g_i18n:getText("licensePlatesTextTitle3"))
	self.textElement:setText(text)

	self.symbolColorTitleElement:setText(g_i18n:getText("licensePlatesSymbolColorTitle"))
	self.symbolColorElement:setTexts({
		g_i18n:getText("licensePlatesSymbolColorBlack"),
		g_i18n:getText("licensePlatesSymbolColorGreen"),
		g_i18n:getText("licensePlatesSymbolColorRed")
	})
	self.symbolColorElement:setState(LicensePlatesGui.S2S[symbolColor])
end

-- trim text if necessary
function LicensePlatesGui:onTextChanged()
	local text = self.textElement:getText()

	-- trim if too long
	if #text > 10 then
		self.textElement:setText(text:sub(1,10))
	end
end

-- close gui and send new values to callback
function LicensePlatesGui:onClickOk()
	local isVisible = self.visibilityElement:getIsChecked()
	local text = self.textElement:getText()
	local symbolColor = LicensePlatesGui.S2S[self.symbolColorElement:getState()]

	self:close()
	self.callbackFunc(self.target, isVisible, text, symbolColor)
end

-- just close gui
function LicensePlatesGui:onClickBack()
	self:close()
end
